@@ -8,7 +8,7 @@ fn build_lib() -> Option<String> {
     let lib = vcpkg::Config::new()
         .find_package("gamenetworkingsockets")
         .unwrap();
-    
+
     let include = lib
         .include_paths
         .iter()
@@ -19,13 +19,16 @@ fn build_lib() -> Option<String> {
 
 fn main() {
     let clang_extra_include = build_lib();
-    let mut bindings = bindgen::Builder::default().header("wrapper.h");
+    let mut builder = bindgen::Builder::default();
 
     if let Some(include_path) = clang_extra_include {
-        bindings = bindings.clang_arg(format!("-I{}", include_path));
+        builder = builder.clang_arg(format!("-I{}", include_path));
     }
+    println!("{:?}", builder);
 
-    let bindings = bindings
+    let bindings = builder
+        .header("wrapper.hpp")
+        .clang_arg("-v")
         .parse_callbacks(Box::new(bindgen::CargoCallbacks))
         .generate()
         .expect("Unable to generate bindings");
@@ -37,21 +40,4 @@ fn main() {
 
     println!("cargo:rustc-link-lib=crypt32");
     println!("cargo:rustc-link-lib=USER32");
-
-    /* 
-    for lib in libs().unwrap() {
-        let mut libpath = lib.as_str();
-        if libpath.ends_with(".lib") {
-            libpath = &libpath[..libpath.len() - 4];
-        }
-        println!("cargo:rustc-link-lib={}", libpath);
-    }*/
-    //println!("cargo:rustc-link-lib=crypto");
-    /*
-    let is_debug = env::var("DEBUG").unwrap() == "true";
-    if is_debug {
-        println!("cargo:rustc-link-search=native={}/build/Debug", out_path.into_os_string().into_string().unwrap());
-    } else {
-        println!("cargo:rustc-link-search=native={}/build/Release", out_path.into_os_string().into_string().unwrap());
-    } */
 }
